import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

void main() {
  runApp(new FontAwesomeGalleryApp());
}

class FontAwesomeGalleryApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      title: 'Font Awesome Flutter Gallery',
      theme: new ThemeData(
        iconTheme: new IconThemeData(size: 36.0, color: Colors.black87),
        primarySwatch: Colors.blueGrey,
        textTheme: new TextTheme(
          body1: new TextStyle(fontSize: 16.0, color: Colors.black87),
        ),
      ),
      home: new FontAwesomeGalleryHome(),
    );
  }
}

class FontAwesomeGalleryHome extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => new FontAwesomeGalleryHomeState();
}

class FontAwesomeGalleryHomeState extends State<FontAwesomeGalleryHome> {
  var _searchTerm = "";
  var _isSearching = false;

  @override
  Widget build(BuildContext context) {
    final filteredIcons = icons
        .where((icon) =>
            _searchTerm.isEmpty ||
            icon.title.toLowerCase().contains(_searchTerm.toLowerCase()))
        .toList();
    final orientation = MediaQuery.of(context).orientation;

    return new Scaffold(
      appBar: _isSearching ? _searchBar(context) : _titleBar(),
      body: new GridView.builder(
          itemCount: filteredIcons.length,
          gridDelegate: new SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: orientation == Orientation.portrait ? 2 : 3,
          ),
          itemBuilder: (context, index) {
            final icon = filteredIcons[index];

            return new InkWell(
              onTap: () {
                Navigator.push(
                  context,
                  new MaterialPageRoute<Null>(
                    builder: (BuildContext context) {
                      return new GestureDetector(
                        onTap: () {
                          Navigator.of(context).pop();
                        },
                        child: new Container(
                          color: Colors.white,
                          child: new SizedBox.expand(
                            child: new Hero(
                              tag: icon,
                              child: new Icon(
                                icon.iconData,
                                size: 100.0,
                              ),
                            ),
                          ),
                        ),
                      );
                    },
                  ),
                );
              },
              child: new Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  new Hero(tag: icon, child: new Icon(icon.iconData)),
                  new Container(
                    padding: new EdgeInsets.only(top: 16.0),
                    child: new Text(icon.title),
                  )
                ],
              ),
            );
          }),
    );
  }

  AppBar _titleBar() {
    return new AppBar(
      title: new Text("Font Awesome Flutter Gallery"),
      actions: [
        new IconButton(
            icon: new Icon(FontAwesomeIcons.search),
            onPressed: () {
              ModalRoute.of(context).addLocalHistoryEntry(
                new LocalHistoryEntry(
                  onRemove: () {
                    setState(() {
                      _searchTerm = "";
                      _isSearching = false;
                    });
                  },
                ),
              );

              setState(() {
                _isSearching = true;
              });
            })
      ],
    );
  }

  AppBar _searchBar(BuildContext context) {
    return new AppBar(
      leading: new IconButton(
        icon: new Icon(FontAwesomeIcons.arrowLeft),
        onPressed: () {
          setState(
            () {
              Navigator.pop(context);
              _isSearching = false;
              _searchTerm = "";
            },
          );
        },
      ),
      title: new TextField(
        onChanged: (text) => setState(() => _searchTerm = text),
        autofocus: true,
        style: new TextStyle(fontSize: 18.0),
        decoration: new InputDecoration(hideDivider: true),
      ),
    );
  }
}

final icons = <IconDefinition>[
  new IconDefinition(FontAwesomeIcons.accessibleIcon, 'accessibleIcon'),
  new IconDefinition(FontAwesomeIcons.accusoft, 'accusoft'),
  new IconDefinition(FontAwesomeIcons.addressBook, 'addressBook'),
  new IconDefinition(FontAwesomeIcons.addressBookO, 'addressBookO'),
  new IconDefinition(FontAwesomeIcons.addressCard, 'addressCard'),
  new IconDefinition(FontAwesomeIcons.addressCardO, 'addressCardO'),
  new IconDefinition(FontAwesomeIcons.adjust, 'adjust'),
  new IconDefinition(FontAwesomeIcons.adn, 'adn'),
  new IconDefinition(FontAwesomeIcons.adversal, 'adversal'),
  new IconDefinition(FontAwesomeIcons.affiliatetheme, 'affiliatetheme'),
  new IconDefinition(FontAwesomeIcons.algolia, 'algolia'),
  new IconDefinition(FontAwesomeIcons.alignCenter, 'alignCenter'),
  new IconDefinition(FontAwesomeIcons.alignJustify, 'alignJustify'),
  new IconDefinition(FontAwesomeIcons.alignLeft, 'alignLeft'),
  new IconDefinition(FontAwesomeIcons.alignRight, 'alignRight'),
  new IconDefinition(FontAwesomeIcons.amazon, 'amazon'),
  new IconDefinition(FontAwesomeIcons.amazonPay, 'amazonPay'),
  new IconDefinition(FontAwesomeIcons.ambulance, 'ambulance'),
  new IconDefinition(FontAwesomeIcons.americanSignLanguageInterpreting,
      'americanSignLanguageInterpreting'),
  new IconDefinition(FontAwesomeIcons.amilia, 'amilia'),
  new IconDefinition(FontAwesomeIcons.anchor, 'anchor'),
  new IconDefinition(FontAwesomeIcons.android, 'android'),
  new IconDefinition(FontAwesomeIcons.angellist, 'angellist'),
  new IconDefinition(FontAwesomeIcons.angleDoubleDown, 'angleDoubleDown'),
  new IconDefinition(FontAwesomeIcons.angleDoubleLeft, 'angleDoubleLeft'),
  new IconDefinition(FontAwesomeIcons.angleDoubleRight, 'angleDoubleRight'),
  new IconDefinition(FontAwesomeIcons.angleDoubleUp, 'angleDoubleUp'),
  new IconDefinition(FontAwesomeIcons.angleDown, 'angleDown'),
  new IconDefinition(FontAwesomeIcons.angleLeft, 'angleLeft'),
  new IconDefinition(FontAwesomeIcons.angleRight, 'angleRight'),
  new IconDefinition(FontAwesomeIcons.angleUp, 'angleUp'),
  new IconDefinition(FontAwesomeIcons.angrycreative, 'angrycreative'),
  new IconDefinition(FontAwesomeIcons.angular, 'angular'),
  new IconDefinition(FontAwesomeIcons.apper, 'apper'),
  new IconDefinition(FontAwesomeIcons.apple, 'apple'),
  new IconDefinition(FontAwesomeIcons.applePay, 'applePay'),
  new IconDefinition(FontAwesomeIcons.appStore, 'appStore'),
  new IconDefinition(FontAwesomeIcons.appStoreIos, 'appStoreIos'),
  new IconDefinition(FontAwesomeIcons.archive, 'archive'),
  new IconDefinition(FontAwesomeIcons.arrowAltCircleDown, 'arrowAltCircleDown'),
  new IconDefinition(
      FontAwesomeIcons.arrowAltCircleDownO, 'arrowAltCircleDownO'),
  new IconDefinition(FontAwesomeIcons.arrowAltCircleLeft, 'arrowAltCircleLeft'),
  new IconDefinition(
      FontAwesomeIcons.arrowAltCircleLeftO, 'arrowAltCircleLeftO'),
  new IconDefinition(
      FontAwesomeIcons.arrowAltCircleRight, 'arrowAltCircleRight'),
  new IconDefinition(
      FontAwesomeIcons.arrowAltCircleRightO, 'arrowAltCircleRightO'),
  new IconDefinition(FontAwesomeIcons.arrowAltCircleUp, 'arrowAltCircleUp'),
  new IconDefinition(FontAwesomeIcons.arrowAltCircleUpO, 'arrowAltCircleUpO'),
  new IconDefinition(FontAwesomeIcons.arrowCircleDown, 'arrowCircleDown'),
  new IconDefinition(FontAwesomeIcons.arrowCircleLeft, 'arrowCircleLeft'),
  new IconDefinition(FontAwesomeIcons.arrowCircleRight, 'arrowCircleRight'),
  new IconDefinition(FontAwesomeIcons.arrowCircleUp, 'arrowCircleUp'),
  new IconDefinition(FontAwesomeIcons.arrowDown, 'arrowDown'),
  new IconDefinition(FontAwesomeIcons.arrowLeft, 'arrowLeft'),
  new IconDefinition(FontAwesomeIcons.arrowRight, 'arrowRight'),
  new IconDefinition(FontAwesomeIcons.arrowsAlt, 'arrowsAlt'),
  new IconDefinition(FontAwesomeIcons.arrowsAltH, 'arrowsAltH'),
  new IconDefinition(FontAwesomeIcons.arrowsAltV, 'arrowsAltV'),
  new IconDefinition(FontAwesomeIcons.arrowUp, 'arrowUp'),
  new IconDefinition(
      FontAwesomeIcons.assistiveListeningSystems, 'assistiveListeningSystems'),
  new IconDefinition(FontAwesomeIcons.asterisk, 'asterisk'),
  new IconDefinition(FontAwesomeIcons.asymmetrik, 'asymmetrik'),
  new IconDefinition(FontAwesomeIcons.at, 'at'),
  new IconDefinition(FontAwesomeIcons.audible, 'audible'),
  new IconDefinition(FontAwesomeIcons.audioDescription, 'audioDescription'),
  new IconDefinition(FontAwesomeIcons.autoprefixer, 'autoprefixer'),
  new IconDefinition(FontAwesomeIcons.avianex, 'avianex'),
  new IconDefinition(FontAwesomeIcons.aviato, 'aviato'),
  new IconDefinition(FontAwesomeIcons.aws, 'aws'),
  new IconDefinition(FontAwesomeIcons.backward, 'backward'),
  new IconDefinition(FontAwesomeIcons.balanceScale, 'balanceScale'),
  new IconDefinition(FontAwesomeIcons.ban, 'ban'),
  new IconDefinition(FontAwesomeIcons.bandcamp, 'bandcamp'),
  new IconDefinition(FontAwesomeIcons.barcode, 'barcode'),
  new IconDefinition(FontAwesomeIcons.bars, 'bars'),
  new IconDefinition(FontAwesomeIcons.bath, 'bath'),
  new IconDefinition(FontAwesomeIcons.batteryEmpty, 'batteryEmpty'),
  new IconDefinition(FontAwesomeIcons.batteryFull, 'batteryFull'),
  new IconDefinition(FontAwesomeIcons.batteryHalf, 'batteryHalf'),
  new IconDefinition(FontAwesomeIcons.batteryQuarter, 'batteryQuarter'),
  new IconDefinition(
      FontAwesomeIcons.batteryThreeQuarters, 'batteryThreeQuarters'),
  new IconDefinition(FontAwesomeIcons.bed, 'bed'),
  new IconDefinition(FontAwesomeIcons.beer, 'beer'),
  new IconDefinition(FontAwesomeIcons.behance, 'behance'),
  new IconDefinition(FontAwesomeIcons.behanceSquare, 'behanceSquare'),
  new IconDefinition(FontAwesomeIcons.bell, 'bell'),
  new IconDefinition(FontAwesomeIcons.bellO, 'bellO'),
  new IconDefinition(FontAwesomeIcons.bellSlash, 'bellSlash'),
  new IconDefinition(FontAwesomeIcons.bellSlashO, 'bellSlashO'),
  new IconDefinition(FontAwesomeIcons.bicycle, 'bicycle'),
  new IconDefinition(FontAwesomeIcons.bimobject, 'bimobject'),
  new IconDefinition(FontAwesomeIcons.binoculars, 'binoculars'),
  new IconDefinition(FontAwesomeIcons.birthdayCake, 'birthdayCake'),
  new IconDefinition(FontAwesomeIcons.bitbucket, 'bitbucket'),
  new IconDefinition(FontAwesomeIcons.bitcoin, 'bitcoin'),
  new IconDefinition(FontAwesomeIcons.bity, 'bity'),
  new IconDefinition(FontAwesomeIcons.blackberry, 'blackberry'),
  new IconDefinition(FontAwesomeIcons.blackTie, 'blackTie'),
  new IconDefinition(FontAwesomeIcons.blind, 'blind'),
  new IconDefinition(FontAwesomeIcons.blogger, 'blogger'),
  new IconDefinition(FontAwesomeIcons.bloggerB, 'bloggerB'),
  new IconDefinition(FontAwesomeIcons.bluetooth, 'bluetooth'),
  new IconDefinition(FontAwesomeIcons.bluetoothB, 'bluetoothB'),
  new IconDefinition(FontAwesomeIcons.bold, 'bold'),
  new IconDefinition(FontAwesomeIcons.bolt, 'bolt'),
  new IconDefinition(FontAwesomeIcons.bomb, 'bomb'),
  new IconDefinition(FontAwesomeIcons.book, 'book'),
  new IconDefinition(FontAwesomeIcons.bookmark, 'bookmark'),
  new IconDefinition(FontAwesomeIcons.bookmarkO, 'bookmarkO'),
  new IconDefinition(FontAwesomeIcons.braille, 'braille'),
  new IconDefinition(FontAwesomeIcons.briefcase, 'briefcase'),
  new IconDefinition(FontAwesomeIcons.btc, 'btc'),
  new IconDefinition(FontAwesomeIcons.bug, 'bug'),
  new IconDefinition(FontAwesomeIcons.building, 'building'),
  new IconDefinition(FontAwesomeIcons.buildingO, 'buildingO'),
  new IconDefinition(FontAwesomeIcons.bullhorn, 'bullhorn'),
  new IconDefinition(FontAwesomeIcons.bullseye, 'bullseye'),
  new IconDefinition(FontAwesomeIcons.buromobelexperte, 'buromobelexperte'),
  new IconDefinition(FontAwesomeIcons.bus, 'bus'),
  new IconDefinition(FontAwesomeIcons.buysellads, 'buysellads'),
  new IconDefinition(FontAwesomeIcons.calculator, 'calculator'),
  new IconDefinition(FontAwesomeIcons.calendar, 'calendar'),
  new IconDefinition(FontAwesomeIcons.calendarAlt, 'calendarAlt'),
  new IconDefinition(FontAwesomeIcons.calendarAltO, 'calendarAltO'),
  new IconDefinition(FontAwesomeIcons.calendarCheck, 'calendarCheck'),
  new IconDefinition(FontAwesomeIcons.calendarCheckO, 'calendarCheckO'),
  new IconDefinition(FontAwesomeIcons.calendarMinus, 'calendarMinus'),
  new IconDefinition(FontAwesomeIcons.calendarMinusO, 'calendarMinusO'),
  new IconDefinition(FontAwesomeIcons.calendarO, 'calendarO'),
  new IconDefinition(FontAwesomeIcons.calendarPlus, 'calendarPlus'),
  new IconDefinition(FontAwesomeIcons.calendarPlusO, 'calendarPlusO'),
  new IconDefinition(FontAwesomeIcons.calendarTimes, 'calendarTimes'),
  new IconDefinition(FontAwesomeIcons.calendarTimesO, 'calendarTimesO'),
  new IconDefinition(FontAwesomeIcons.camera, 'camera'),
  new IconDefinition(FontAwesomeIcons.cameraRetro, 'cameraRetro'),
  new IconDefinition(FontAwesomeIcons.car, 'car'),
  new IconDefinition(FontAwesomeIcons.caretDown, 'caretDown'),
  new IconDefinition(FontAwesomeIcons.caretLeft, 'caretLeft'),
  new IconDefinition(FontAwesomeIcons.caretRight, 'caretRight'),
  new IconDefinition(FontAwesomeIcons.caretSquareDown, 'caretSquareDown'),
  new IconDefinition(FontAwesomeIcons.caretSquareDownO, 'caretSquareDownO'),
  new IconDefinition(FontAwesomeIcons.caretSquareLeft, 'caretSquareLeft'),
  new IconDefinition(FontAwesomeIcons.caretSquareLeftO, 'caretSquareLeftO'),
  new IconDefinition(FontAwesomeIcons.caretSquareRight, 'caretSquareRight'),
  new IconDefinition(FontAwesomeIcons.caretSquareRightO, 'caretSquareRightO'),
  new IconDefinition(FontAwesomeIcons.caretSquareUp, 'caretSquareUp'),
  new IconDefinition(FontAwesomeIcons.caretSquareUpO, 'caretSquareUpO'),
  new IconDefinition(FontAwesomeIcons.caretUp, 'caretUp'),
  new IconDefinition(FontAwesomeIcons.cartArrowDown, 'cartArrowDown'),
  new IconDefinition(FontAwesomeIcons.cartPlus, 'cartPlus'),
  new IconDefinition(FontAwesomeIcons.ccAmazonPay, 'ccAmazonPay'),
  new IconDefinition(FontAwesomeIcons.ccAmex, 'ccAmex'),
  new IconDefinition(FontAwesomeIcons.ccApplePay, 'ccApplePay'),
  new IconDefinition(FontAwesomeIcons.ccDinersClub, 'ccDinersClub'),
  new IconDefinition(FontAwesomeIcons.ccDiscover, 'ccDiscover'),
  new IconDefinition(FontAwesomeIcons.ccJcb, 'ccJcb'),
  new IconDefinition(FontAwesomeIcons.ccMastercard, 'ccMastercard'),
  new IconDefinition(FontAwesomeIcons.ccPaypal, 'ccPaypal'),
  new IconDefinition(FontAwesomeIcons.ccStripe, 'ccStripe'),
  new IconDefinition(FontAwesomeIcons.ccVisa, 'ccVisa'),
  new IconDefinition(FontAwesomeIcons.centercode, 'centercode'),
  new IconDefinition(FontAwesomeIcons.certificate, 'certificate'),
  new IconDefinition(FontAwesomeIcons.chartArea, 'chartArea'),
  new IconDefinition(FontAwesomeIcons.chartBar, 'chartBar'),
  new IconDefinition(FontAwesomeIcons.chartBarO, 'chartBarO'),
  new IconDefinition(FontAwesomeIcons.chartLine, 'chartLine'),
  new IconDefinition(FontAwesomeIcons.chartPie, 'chartPie'),
  new IconDefinition(FontAwesomeIcons.check, 'check'),
  new IconDefinition(FontAwesomeIcons.checkCircle, 'checkCircle'),
  new IconDefinition(FontAwesomeIcons.checkCircleO, 'checkCircleO'),
  new IconDefinition(FontAwesomeIcons.checkSquare, 'checkSquare'),
  new IconDefinition(FontAwesomeIcons.checkSquareO, 'checkSquareO'),
  new IconDefinition(FontAwesomeIcons.chevronCircleDown, 'chevronCircleDown'),
  new IconDefinition(FontAwesomeIcons.chevronCircleLeft, 'chevronCircleLeft'),
  new IconDefinition(FontAwesomeIcons.chevronCircleRight, 'chevronCircleRight'),
  new IconDefinition(FontAwesomeIcons.chevronCircleUp, 'chevronCircleUp'),
  new IconDefinition(FontAwesomeIcons.chevronDown, 'chevronDown'),
  new IconDefinition(FontAwesomeIcons.chevronLeft, 'chevronLeft'),
  new IconDefinition(FontAwesomeIcons.chevronRight, 'chevronRight'),
  new IconDefinition(FontAwesomeIcons.chevronUp, 'chevronUp'),
  new IconDefinition(FontAwesomeIcons.child, 'child'),
  new IconDefinition(FontAwesomeIcons.chrome, 'chrome'),
  new IconDefinition(FontAwesomeIcons.circle, 'circle'),
  new IconDefinition(FontAwesomeIcons.circleNotch, 'circleNotch'),
  new IconDefinition(FontAwesomeIcons.circleO, 'circleO'),
  new IconDefinition(FontAwesomeIcons.clipboard, 'clipboard'),
  new IconDefinition(FontAwesomeIcons.clipboardO, 'clipboardO'),
  new IconDefinition(FontAwesomeIcons.clock, 'clock'),
  new IconDefinition(FontAwesomeIcons.clockO, 'clockO'),
  new IconDefinition(FontAwesomeIcons.clone, 'clone'),
  new IconDefinition(FontAwesomeIcons.cloneO, 'cloneO'),
  new IconDefinition(FontAwesomeIcons.closedCaptioning, 'closedCaptioning'),
  new IconDefinition(FontAwesomeIcons.closedCaptioningO, 'closedCaptioningO'),
  new IconDefinition(FontAwesomeIcons.cloud, 'cloud'),
  new IconDefinition(FontAwesomeIcons.cloudDownloadAlt, 'cloudDownloadAlt'),
  new IconDefinition(FontAwesomeIcons.cloudscale, 'cloudscale'),
  new IconDefinition(FontAwesomeIcons.cloudsmith, 'cloudsmith'),
  new IconDefinition(FontAwesomeIcons.cloudUploadAlt, 'cloudUploadAlt'),
  new IconDefinition(FontAwesomeIcons.cloudversify, 'cloudversify'),
  new IconDefinition(FontAwesomeIcons.code, 'code'),
  new IconDefinition(FontAwesomeIcons.codeBranch, 'codeBranch'),
  new IconDefinition(FontAwesomeIcons.codepen, 'codepen'),
  new IconDefinition(FontAwesomeIcons.codiepie, 'codiepie'),
  new IconDefinition(FontAwesomeIcons.coffee, 'coffee'),
  new IconDefinition(FontAwesomeIcons.cog, 'cog'),
  new IconDefinition(FontAwesomeIcons.cogs, 'cogs'),
  new IconDefinition(FontAwesomeIcons.columns, 'columns'),
  new IconDefinition(FontAwesomeIcons.comment, 'comment'),
  new IconDefinition(FontAwesomeIcons.commentAlt, 'commentAlt'),
  new IconDefinition(FontAwesomeIcons.commentAltO, 'commentAltO'),
  new IconDefinition(FontAwesomeIcons.commentO, 'commentO'),
  new IconDefinition(FontAwesomeIcons.comments, 'comments'),
  new IconDefinition(FontAwesomeIcons.commentsO, 'commentsO'),
  new IconDefinition(FontAwesomeIcons.compass, 'compass'),
  new IconDefinition(FontAwesomeIcons.compassO, 'compassO'),
  new IconDefinition(FontAwesomeIcons.compress, 'compress'),
  new IconDefinition(FontAwesomeIcons.connectdevelop, 'connectdevelop'),
  new IconDefinition(FontAwesomeIcons.contao, 'contao'),
  new IconDefinition(FontAwesomeIcons.copy, 'copy'),
  new IconDefinition(FontAwesomeIcons.copyO, 'copyO'),
  new IconDefinition(FontAwesomeIcons.copyright, 'copyright'),
  new IconDefinition(FontAwesomeIcons.copyrightO, 'copyrightO'),
  new IconDefinition(FontAwesomeIcons.cpanel, 'cpanel'),
  new IconDefinition(FontAwesomeIcons.creativeCommons, 'creativeCommons'),
  new IconDefinition(FontAwesomeIcons.creditCard, 'creditCard'),
  new IconDefinition(FontAwesomeIcons.creditCardO, 'creditCardO'),
  new IconDefinition(FontAwesomeIcons.crop, 'crop'),
  new IconDefinition(FontAwesomeIcons.crosshairs, 'crosshairs'),
  new IconDefinition(FontAwesomeIcons.css3, 'css3'),
  new IconDefinition(FontAwesomeIcons.css3Alt, 'css3Alt'),
  new IconDefinition(FontAwesomeIcons.cube, 'cube'),
  new IconDefinition(FontAwesomeIcons.cubes, 'cubes'),
  new IconDefinition(FontAwesomeIcons.cut, 'cut'),
  new IconDefinition(FontAwesomeIcons.cuttlefish, 'cuttlefish'),
  new IconDefinition(FontAwesomeIcons.dAndD, 'dAndD'),
  new IconDefinition(FontAwesomeIcons.dashcube, 'dashcube'),
  new IconDefinition(FontAwesomeIcons.database, 'database'),
  new IconDefinition(FontAwesomeIcons.deaf, 'deaf'),
  new IconDefinition(FontAwesomeIcons.delicious, 'delicious'),
  new IconDefinition(FontAwesomeIcons.deploydog, 'deploydog'),
  new IconDefinition(FontAwesomeIcons.deskpro, 'deskpro'),
  new IconDefinition(FontAwesomeIcons.desktop, 'desktop'),
  new IconDefinition(FontAwesomeIcons.deviantart, 'deviantart'),
  new IconDefinition(FontAwesomeIcons.digg, 'digg'),
  new IconDefinition(FontAwesomeIcons.digitalOcean, 'digitalOcean'),
  new IconDefinition(FontAwesomeIcons.discord, 'discord'),
  new IconDefinition(FontAwesomeIcons.discourse, 'discourse'),
  new IconDefinition(FontAwesomeIcons.dochub, 'dochub'),
  new IconDefinition(FontAwesomeIcons.docker, 'docker'),
  new IconDefinition(FontAwesomeIcons.dollarSign, 'dollarSign'),
  new IconDefinition(FontAwesomeIcons.dotCircle, 'dotCircle'),
  new IconDefinition(FontAwesomeIcons.dotCircleO, 'dotCircleO'),
  new IconDefinition(FontAwesomeIcons.download, 'download'),
  new IconDefinition(FontAwesomeIcons.draft2digital, 'draft2digital'),
  new IconDefinition(FontAwesomeIcons.dribbble, 'dribbble'),
  new IconDefinition(FontAwesomeIcons.dribbbleSquare, 'dribbbleSquare'),
  new IconDefinition(FontAwesomeIcons.dropbox, 'dropbox'),
  new IconDefinition(FontAwesomeIcons.drupal, 'drupal'),
  new IconDefinition(FontAwesomeIcons.dyalog, 'dyalog'),
  new IconDefinition(FontAwesomeIcons.earlybirds, 'earlybirds'),
  new IconDefinition(FontAwesomeIcons.edge, 'edge'),
  new IconDefinition(FontAwesomeIcons.edit, 'edit'),
  new IconDefinition(FontAwesomeIcons.editO, 'editO'),
  new IconDefinition(FontAwesomeIcons.eject, 'eject'),
  new IconDefinition(FontAwesomeIcons.ellipsisH, 'ellipsisH'),
  new IconDefinition(FontAwesomeIcons.ellipsisV, 'ellipsisV'),
  new IconDefinition(FontAwesomeIcons.ember, 'ember'),
  new IconDefinition(FontAwesomeIcons.empire, 'empire'),
  new IconDefinition(FontAwesomeIcons.envelope, 'envelope'),
  new IconDefinition(FontAwesomeIcons.envelopeO, 'envelopeO'),
  new IconDefinition(FontAwesomeIcons.envelopeOpen, 'envelopeOpen'),
  new IconDefinition(FontAwesomeIcons.envelopeOpenO, 'envelopeOpenO'),
  new IconDefinition(FontAwesomeIcons.envelopeSquare, 'envelopeSquare'),
  new IconDefinition(FontAwesomeIcons.envira, 'envira'),
  new IconDefinition(FontAwesomeIcons.eraser, 'eraser'),
  new IconDefinition(FontAwesomeIcons.erlang, 'erlang'),
  new IconDefinition(FontAwesomeIcons.ethereum, 'ethereum'),
  new IconDefinition(FontAwesomeIcons.etsy, 'etsy'),
  new IconDefinition(FontAwesomeIcons.euroSign, 'euroSign'),
  new IconDefinition(FontAwesomeIcons.exchangeAlt, 'exchangeAlt'),
  new IconDefinition(FontAwesomeIcons.exclamation, 'exclamation'),
  new IconDefinition(FontAwesomeIcons.exclamationCircle, 'exclamationCircle'),
  new IconDefinition(
      FontAwesomeIcons.exclamationTriangle, 'exclamationTriangle'),
  new IconDefinition(FontAwesomeIcons.expand, 'expand'),
  new IconDefinition(FontAwesomeIcons.expandArrowsAlt, 'expandArrowsAlt'),
  new IconDefinition(FontAwesomeIcons.expeditedssl, 'expeditedssl'),
  new IconDefinition(FontAwesomeIcons.externalLinkAlt, 'externalLinkAlt'),
  new IconDefinition(
      FontAwesomeIcons.externalLinkSquareAlt, 'externalLinkSquareAlt'),
  new IconDefinition(FontAwesomeIcons.eye, 'eye'),
  new IconDefinition(FontAwesomeIcons.eyeDropper, 'eyeDropper'),
  new IconDefinition(FontAwesomeIcons.eyeSlash, 'eyeSlash'),
  new IconDefinition(FontAwesomeIcons.eyeSlashO, 'eyeSlashO'),
  new IconDefinition(FontAwesomeIcons.facebook, 'facebook'),
  new IconDefinition(FontAwesomeIcons.facebookF, 'facebookF'),
  new IconDefinition(FontAwesomeIcons.facebookMessenger, 'facebookMessenger'),
  new IconDefinition(FontAwesomeIcons.facebookSquare, 'facebookSquare'),
  new IconDefinition(FontAwesomeIcons.fastBackward, 'fastBackward'),
  new IconDefinition(FontAwesomeIcons.fastForward, 'fastForward'),
  new IconDefinition(FontAwesomeIcons.fax, 'fax'),
  new IconDefinition(FontAwesomeIcons.female, 'female'),
  new IconDefinition(FontAwesomeIcons.fighterJet, 'fighterJet'),
  new IconDefinition(FontAwesomeIcons.file, 'file'),
  new IconDefinition(FontAwesomeIcons.fileAlt, 'fileAlt'),
  new IconDefinition(FontAwesomeIcons.fileAltO, 'fileAltO'),
  new IconDefinition(FontAwesomeIcons.fileArchive, 'fileArchive'),
  new IconDefinition(FontAwesomeIcons.fileArchiveO, 'fileArchiveO'),
  new IconDefinition(FontAwesomeIcons.fileAudio, 'fileAudio'),
  new IconDefinition(FontAwesomeIcons.fileAudioO, 'fileAudioO'),
  new IconDefinition(FontAwesomeIcons.fileCode, 'fileCode'),
  new IconDefinition(FontAwesomeIcons.fileCodeO, 'fileCodeO'),
  new IconDefinition(FontAwesomeIcons.fileExcel, 'fileExcel'),
  new IconDefinition(FontAwesomeIcons.fileExcelO, 'fileExcelO'),
  new IconDefinition(FontAwesomeIcons.fileImage, 'fileImage'),
  new IconDefinition(FontAwesomeIcons.fileImageO, 'fileImageO'),
  new IconDefinition(FontAwesomeIcons.fileO, 'fileO'),
  new IconDefinition(FontAwesomeIcons.filePdf, 'filePdf'),
  new IconDefinition(FontAwesomeIcons.filePdfO, 'filePdfO'),
  new IconDefinition(FontAwesomeIcons.filePowerpoint, 'filePowerpoint'),
  new IconDefinition(FontAwesomeIcons.filePowerpointO, 'filePowerpointO'),
  new IconDefinition(FontAwesomeIcons.fileVideo, 'fileVideo'),
  new IconDefinition(FontAwesomeIcons.fileVideoO, 'fileVideoO'),
  new IconDefinition(FontAwesomeIcons.fileWord, 'fileWord'),
  new IconDefinition(FontAwesomeIcons.fileWordO, 'fileWordO'),
  new IconDefinition(FontAwesomeIcons.film, 'film'),
  new IconDefinition(FontAwesomeIcons.filter, 'filter'),
  new IconDefinition(FontAwesomeIcons.fire, 'fire'),
  new IconDefinition(FontAwesomeIcons.fireExtinguisher, 'fireExtinguisher'),
  new IconDefinition(FontAwesomeIcons.firefox, 'firefox'),
  new IconDefinition(FontAwesomeIcons.firstdraft, 'firstdraft'),
  new IconDefinition(FontAwesomeIcons.firstOrder, 'firstOrder'),
  new IconDefinition(FontAwesomeIcons.fiveHundredPx, 'fiveHundredPx'),
  new IconDefinition(FontAwesomeIcons.flag, 'flag'),
  new IconDefinition(FontAwesomeIcons.flagCheckered, 'flagCheckered'),
  new IconDefinition(FontAwesomeIcons.flagO, 'flagO'),
  new IconDefinition(FontAwesomeIcons.flask, 'flask'),
  new IconDefinition(FontAwesomeIcons.flickr, 'flickr'),
  new IconDefinition(FontAwesomeIcons.fly, 'fly'),
  new IconDefinition(FontAwesomeIcons.folder, 'folder'),
  new IconDefinition(FontAwesomeIcons.folderO, 'folderO'),
  new IconDefinition(FontAwesomeIcons.folderOpen, 'folderOpen'),
  new IconDefinition(FontAwesomeIcons.folderOpenO, 'folderOpenO'),
  new IconDefinition(FontAwesomeIcons.font, 'font'),
  new IconDefinition(FontAwesomeIcons.fontAwesome, 'fontAwesome'),
  new IconDefinition(FontAwesomeIcons.fontAwesomeAlt, 'fontAwesomeAlt'),
  new IconDefinition(FontAwesomeIcons.fontAwesomeFlag, 'fontAwesomeFlag'),
  new IconDefinition(FontAwesomeIcons.fonticons, 'fonticons'),
  new IconDefinition(FontAwesomeIcons.fonticonsFi, 'fonticonsFi'),
  new IconDefinition(FontAwesomeIcons.fortAwesome, 'fortAwesome'),
  new IconDefinition(FontAwesomeIcons.fortAwesomeAlt, 'fortAwesomeAlt'),
  new IconDefinition(FontAwesomeIcons.forumbee, 'forumbee'),
  new IconDefinition(FontAwesomeIcons.forward, 'forward'),
  new IconDefinition(FontAwesomeIcons.foursquare, 'foursquare'),
  new IconDefinition(FontAwesomeIcons.foursquareO, 'foursquareO'),
  new IconDefinition(FontAwesomeIcons.freebsd, 'freebsd'),
  new IconDefinition(FontAwesomeIcons.freeCodeCamp, 'freeCodeCamp'),
  new IconDefinition(FontAwesomeIcons.frown, 'frown'),
  new IconDefinition(FontAwesomeIcons.frownO, 'frownO'),
  new IconDefinition(FontAwesomeIcons.futbol, 'futbol'),
  new IconDefinition(FontAwesomeIcons.futbolO, 'futbolO'),
  new IconDefinition(FontAwesomeIcons.gamepad, 'gamepad'),
  new IconDefinition(FontAwesomeIcons.gavel, 'gavel'),
  new IconDefinition(FontAwesomeIcons.gem, 'gem'),
  new IconDefinition(FontAwesomeIcons.gemO, 'gemO'),
  new IconDefinition(FontAwesomeIcons.genderless, 'genderless'),
  new IconDefinition(FontAwesomeIcons.getPocket, 'getPocket'),
  new IconDefinition(FontAwesomeIcons.gg, 'gg'),
  new IconDefinition(FontAwesomeIcons.ggCircle, 'ggCircle'),
  new IconDefinition(FontAwesomeIcons.gift, 'gift'),
  new IconDefinition(FontAwesomeIcons.git, 'git'),
  new IconDefinition(FontAwesomeIcons.github, 'github'),
  new IconDefinition(FontAwesomeIcons.githubAlt, 'githubAlt'),
  new IconDefinition(FontAwesomeIcons.githubSquare, 'githubSquare'),
  new IconDefinition(FontAwesomeIcons.gitkraken, 'gitkraken'),
  new IconDefinition(FontAwesomeIcons.gitlab, 'gitlab'),
  new IconDefinition(FontAwesomeIcons.gitSquare, 'gitSquare'),
  new IconDefinition(FontAwesomeIcons.gitter, 'gitter'),
  new IconDefinition(FontAwesomeIcons.glassMartini, 'glassMartini'),
  new IconDefinition(FontAwesomeIcons.glide, 'glide'),
  new IconDefinition(FontAwesomeIcons.glideG, 'glideG'),
  new IconDefinition(FontAwesomeIcons.globe, 'globe'),
  new IconDefinition(FontAwesomeIcons.gofore, 'gofore'),
  new IconDefinition(FontAwesomeIcons.goodreads, 'goodreads'),
  new IconDefinition(FontAwesomeIcons.goodreadsG, 'goodreadsG'),
  new IconDefinition(FontAwesomeIcons.google, 'google'),
  new IconDefinition(FontAwesomeIcons.googleDrive, 'googleDrive'),
  new IconDefinition(FontAwesomeIcons.googlePlay, 'googlePlay'),
  new IconDefinition(FontAwesomeIcons.googlePlus, 'googlePlus'),
  new IconDefinition(FontAwesomeIcons.googlePlusG, 'googlePlusG'),
  new IconDefinition(FontAwesomeIcons.googlePlusSquare, 'googlePlusSquare'),
  new IconDefinition(FontAwesomeIcons.googleWallet, 'googleWallet'),
  new IconDefinition(FontAwesomeIcons.graduationCap, 'graduationCap'),
  new IconDefinition(FontAwesomeIcons.gratipay, 'gratipay'),
  new IconDefinition(FontAwesomeIcons.grav, 'grav'),
  new IconDefinition(FontAwesomeIcons.gripfire, 'gripfire'),
  new IconDefinition(FontAwesomeIcons.grunt, 'grunt'),
  new IconDefinition(FontAwesomeIcons.gulp, 'gulp'),
  new IconDefinition(FontAwesomeIcons.hackerNews, 'hackerNews'),
  new IconDefinition(FontAwesomeIcons.hackerNewsSquare, 'hackerNewsSquare'),
  new IconDefinition(FontAwesomeIcons.handLizard, 'handLizard'),
  new IconDefinition(FontAwesomeIcons.handLizardO, 'handLizardO'),
  new IconDefinition(FontAwesomeIcons.handPaper, 'handPaper'),
  new IconDefinition(FontAwesomeIcons.handPaperO, 'handPaperO'),
  new IconDefinition(FontAwesomeIcons.handPeace, 'handPeace'),
  new IconDefinition(FontAwesomeIcons.handPeaceO, 'handPeaceO'),
  new IconDefinition(FontAwesomeIcons.handPointDown, 'handPointDown'),
  new IconDefinition(FontAwesomeIcons.handPointDownO, 'handPointDownO'),
  new IconDefinition(FontAwesomeIcons.handPointer, 'handPointer'),
  new IconDefinition(FontAwesomeIcons.handPointerO, 'handPointerO'),
  new IconDefinition(FontAwesomeIcons.handPointLeft, 'handPointLeft'),
  new IconDefinition(FontAwesomeIcons.handPointLeftO, 'handPointLeftO'),
  new IconDefinition(FontAwesomeIcons.handPointRight, 'handPointRight'),
  new IconDefinition(FontAwesomeIcons.handPointRightO, 'handPointRightO'),
  new IconDefinition(FontAwesomeIcons.handPointUp, 'handPointUp'),
  new IconDefinition(FontAwesomeIcons.handPointUpO, 'handPointUpO'),
  new IconDefinition(FontAwesomeIcons.handRock, 'handRock'),
  new IconDefinition(FontAwesomeIcons.handRockO, 'handRockO'),
  new IconDefinition(FontAwesomeIcons.handScissors, 'handScissors'),
  new IconDefinition(FontAwesomeIcons.handScissorsO, 'handScissorsO'),
  new IconDefinition(FontAwesomeIcons.handshake, 'handshake'),
  new IconDefinition(FontAwesomeIcons.handshakeO, 'handshakeO'),
  new IconDefinition(FontAwesomeIcons.handSpock, 'handSpock'),
  new IconDefinition(FontAwesomeIcons.handSpockO, 'handSpockO'),
  new IconDefinition(FontAwesomeIcons.hashtag, 'hashtag'),
  new IconDefinition(FontAwesomeIcons.hdd, 'hdd'),
  new IconDefinition(FontAwesomeIcons.hddO, 'hddO'),
  new IconDefinition(FontAwesomeIcons.heading, 'heading'),
  new IconDefinition(FontAwesomeIcons.headphones, 'headphones'),
  new IconDefinition(FontAwesomeIcons.heart, 'heart'),
  new IconDefinition(FontAwesomeIcons.heartbeat, 'heartbeat'),
  new IconDefinition(FontAwesomeIcons.heartO, 'heartO'),
  new IconDefinition(FontAwesomeIcons.hireAHelper, 'hireAHelper'),
  new IconDefinition(FontAwesomeIcons.history, 'history'),
  new IconDefinition(FontAwesomeIcons.home, 'home'),
  new IconDefinition(FontAwesomeIcons.hooli, 'hooli'),
  new IconDefinition(FontAwesomeIcons.hospital, 'hospital'),
  new IconDefinition(FontAwesomeIcons.hospitalO, 'hospitalO'),
  new IconDefinition(FontAwesomeIcons.hotjar, 'hotjar'),
  new IconDefinition(FontAwesomeIcons.hourglass, 'hourglass'),
  new IconDefinition(FontAwesomeIcons.hourglassEnd, 'hourglassEnd'),
  new IconDefinition(FontAwesomeIcons.hourglassHalf, 'hourglassHalf'),
  new IconDefinition(FontAwesomeIcons.hourglassO, 'hourglassO'),
  new IconDefinition(FontAwesomeIcons.hourglassStart, 'hourglassStart'),
  new IconDefinition(FontAwesomeIcons.houzz, 'houzz'),
  new IconDefinition(FontAwesomeIcons.hSquare, 'hSquare'),
  new IconDefinition(FontAwesomeIcons.html5, 'html5'),
  new IconDefinition(FontAwesomeIcons.hubspot, 'hubspot'),
  new IconDefinition(FontAwesomeIcons.iCursor, 'iCursor'),
  new IconDefinition(FontAwesomeIcons.idBadge, 'idBadge'),
  new IconDefinition(FontAwesomeIcons.idBadgeO, 'idBadgeO'),
  new IconDefinition(FontAwesomeIcons.idCard, 'idCard'),
  new IconDefinition(FontAwesomeIcons.idCardO, 'idCardO'),
  new IconDefinition(FontAwesomeIcons.image, 'image'),
  new IconDefinition(FontAwesomeIcons.imageO, 'imageO'),
  new IconDefinition(FontAwesomeIcons.images, 'images'),
  new IconDefinition(FontAwesomeIcons.imagesO, 'imagesO'),
  new IconDefinition(FontAwesomeIcons.imdb, 'imdb'),
  new IconDefinition(FontAwesomeIcons.inbox, 'inbox'),
  new IconDefinition(FontAwesomeIcons.indent, 'indent'),
  new IconDefinition(FontAwesomeIcons.industry, 'industry'),
  new IconDefinition(FontAwesomeIcons.info, 'info'),
  new IconDefinition(FontAwesomeIcons.infoCircle, 'infoCircle'),
  new IconDefinition(FontAwesomeIcons.instagram, 'instagram'),
  new IconDefinition(FontAwesomeIcons.internetExplorer, 'internetExplorer'),
  new IconDefinition(FontAwesomeIcons.ioxhost, 'ioxhost'),
  new IconDefinition(FontAwesomeIcons.italic, 'italic'),
  new IconDefinition(FontAwesomeIcons.itunes, 'itunes'),
  new IconDefinition(FontAwesomeIcons.itunesNote, 'itunesNote'),
  new IconDefinition(FontAwesomeIcons.jenkins, 'jenkins'),
  new IconDefinition(FontAwesomeIcons.joget, 'joget'),
  new IconDefinition(FontAwesomeIcons.joomla, 'joomla'),
  new IconDefinition(FontAwesomeIcons.js, 'js'),
  new IconDefinition(FontAwesomeIcons.jsfiddle, 'jsfiddle'),
  new IconDefinition(FontAwesomeIcons.jsSquare, 'jsSquare'),
  new IconDefinition(FontAwesomeIcons.key, 'key'),
  new IconDefinition(FontAwesomeIcons.keyboard, 'keyboard'),
  new IconDefinition(FontAwesomeIcons.keyboardO, 'keyboardO'),
  new IconDefinition(FontAwesomeIcons.keycdn, 'keycdn'),
  new IconDefinition(FontAwesomeIcons.kickstarter, 'kickstarter'),
  new IconDefinition(FontAwesomeIcons.kickstarterK, 'kickstarterK'),
  new IconDefinition(FontAwesomeIcons.korvue, 'korvue'),
  new IconDefinition(FontAwesomeIcons.language, 'language'),
  new IconDefinition(FontAwesomeIcons.laptop, 'laptop'),
  new IconDefinition(FontAwesomeIcons.laravel, 'laravel'),
  new IconDefinition(FontAwesomeIcons.lastfm, 'lastfm'),
  new IconDefinition(FontAwesomeIcons.lastfmSquare, 'lastfmSquare'),
  new IconDefinition(FontAwesomeIcons.leaf, 'leaf'),
  new IconDefinition(FontAwesomeIcons.leanpub, 'leanpub'),
  new IconDefinition(FontAwesomeIcons.lemon, 'lemon'),
  new IconDefinition(FontAwesomeIcons.lemonO, 'lemonO'),
  new IconDefinition(FontAwesomeIcons.less, 'less'),
  new IconDefinition(FontAwesomeIcons.levelDownAlt, 'levelDownAlt'),
  new IconDefinition(FontAwesomeIcons.levelUpAlt, 'levelUpAlt'),
  new IconDefinition(FontAwesomeIcons.lifeRing, 'lifeRing'),
  new IconDefinition(FontAwesomeIcons.lifeRingO, 'lifeRingO'),
  new IconDefinition(FontAwesomeIcons.lightbulb, 'lightbulb'),
  new IconDefinition(FontAwesomeIcons.lightbulbO, 'lightbulbO'),
  new IconDefinition(FontAwesomeIcons.line, 'line'),
  new IconDefinition(FontAwesomeIcons.link, 'link'),
  new IconDefinition(FontAwesomeIcons.linkedin, 'linkedin'),
  new IconDefinition(FontAwesomeIcons.linkedinIn, 'linkedinIn'),
  new IconDefinition(FontAwesomeIcons.linode, 'linode'),
  new IconDefinition(FontAwesomeIcons.linux, 'linux'),
  new IconDefinition(FontAwesomeIcons.liraSign, 'liraSign'),
  new IconDefinition(FontAwesomeIcons.list, 'list'),
  new IconDefinition(FontAwesomeIcons.listAlt, 'listAlt'),
  new IconDefinition(FontAwesomeIcons.listAltO, 'listAltO'),
  new IconDefinition(FontAwesomeIcons.listOl, 'listOl'),
  new IconDefinition(FontAwesomeIcons.listUl, 'listUl'),
  new IconDefinition(FontAwesomeIcons.locationArrow, 'locationArrow'),
  new IconDefinition(FontAwesomeIcons.lock, 'lock'),
  new IconDefinition(FontAwesomeIcons.lockOpen, 'lockOpen'),
  new IconDefinition(FontAwesomeIcons.longArrowAltDown, 'longArrowAltDown'),
  new IconDefinition(FontAwesomeIcons.longArrowAltLeft, 'longArrowAltLeft'),
  new IconDefinition(FontAwesomeIcons.longArrowAltRight, 'longArrowAltRight'),
  new IconDefinition(FontAwesomeIcons.longArrowAltUp, 'longArrowAltUp'),
  new IconDefinition(FontAwesomeIcons.lowVision, 'lowVision'),
  new IconDefinition(FontAwesomeIcons.lyft, 'lyft'),
  new IconDefinition(FontAwesomeIcons.magento, 'magento'),
  new IconDefinition(FontAwesomeIcons.magic, 'magic'),
  new IconDefinition(FontAwesomeIcons.magnet, 'magnet'),
  new IconDefinition(FontAwesomeIcons.male, 'male'),
  new IconDefinition(FontAwesomeIcons.map, 'map'),
  new IconDefinition(FontAwesomeIcons.mapMarker, 'mapMarker'),
  new IconDefinition(FontAwesomeIcons.mapMarkerAlt, 'mapMarkerAlt'),
  new IconDefinition(FontAwesomeIcons.mapO, 'mapO'),
  new IconDefinition(FontAwesomeIcons.mapPin, 'mapPin'),
  new IconDefinition(FontAwesomeIcons.mapSigns, 'mapSigns'),
  new IconDefinition(FontAwesomeIcons.mars, 'mars'),
  new IconDefinition(FontAwesomeIcons.marsDouble, 'marsDouble'),
  new IconDefinition(FontAwesomeIcons.marsStroke, 'marsStroke'),
  new IconDefinition(FontAwesomeIcons.marsStrokeH, 'marsStrokeH'),
  new IconDefinition(FontAwesomeIcons.marsStrokeV, 'marsStrokeV'),
  new IconDefinition(FontAwesomeIcons.maxcdn, 'maxcdn'),
  new IconDefinition(FontAwesomeIcons.medapps, 'medapps'),
  new IconDefinition(FontAwesomeIcons.medium, 'medium'),
  new IconDefinition(FontAwesomeIcons.mediumM, 'mediumM'),
  new IconDefinition(FontAwesomeIcons.medkit, 'medkit'),
  new IconDefinition(FontAwesomeIcons.medrt, 'medrt'),
  new IconDefinition(FontAwesomeIcons.meetup, 'meetup'),
  new IconDefinition(FontAwesomeIcons.meh, 'meh'),
  new IconDefinition(FontAwesomeIcons.mehO, 'mehO'),
  new IconDefinition(FontAwesomeIcons.mercury, 'mercury'),
  new IconDefinition(FontAwesomeIcons.microchip, 'microchip'),
  new IconDefinition(FontAwesomeIcons.microphone, 'microphone'),
  new IconDefinition(FontAwesomeIcons.microphoneSlash, 'microphoneSlash'),
  new IconDefinition(FontAwesomeIcons.microsoft, 'microsoft'),
  new IconDefinition(FontAwesomeIcons.minus, 'minus'),
  new IconDefinition(FontAwesomeIcons.minusCircle, 'minusCircle'),
  new IconDefinition(FontAwesomeIcons.minusSquare, 'minusSquare'),
  new IconDefinition(FontAwesomeIcons.minusSquareO, 'minusSquareO'),
  new IconDefinition(FontAwesomeIcons.mix, 'mix'),
  new IconDefinition(FontAwesomeIcons.mixcloud, 'mixcloud'),
  new IconDefinition(FontAwesomeIcons.mizuni, 'mizuni'),
  new IconDefinition(FontAwesomeIcons.mobile, 'mobile'),
  new IconDefinition(FontAwesomeIcons.mobileAlt, 'mobileAlt'),
  new IconDefinition(FontAwesomeIcons.modx, 'modx'),
  new IconDefinition(FontAwesomeIcons.monero, 'monero'),
  new IconDefinition(FontAwesomeIcons.moneyBillAlt, 'moneyBillAlt'),
  new IconDefinition(FontAwesomeIcons.moneyBillAltO, 'moneyBillAltO'),
  new IconDefinition(FontAwesomeIcons.moon, 'moon'),
  new IconDefinition(FontAwesomeIcons.moonO, 'moonO'),
  new IconDefinition(FontAwesomeIcons.motorcycle, 'motorcycle'),
  new IconDefinition(FontAwesomeIcons.mousePointer, 'mousePointer'),
  new IconDefinition(FontAwesomeIcons.music, 'music'),
  new IconDefinition(FontAwesomeIcons.napster, 'napster'),
  new IconDefinition(FontAwesomeIcons.neuter, 'neuter'),
  new IconDefinition(FontAwesomeIcons.newspaper, 'newspaper'),
  new IconDefinition(FontAwesomeIcons.newspaperO, 'newspaperO'),
  new IconDefinition(FontAwesomeIcons.nintendoSwitch, 'nintendoSwitch'),
  new IconDefinition(FontAwesomeIcons.node, 'node'),
  new IconDefinition(FontAwesomeIcons.nodeJs, 'nodeJs'),
  new IconDefinition(FontAwesomeIcons.npm, 'npm'),
  new IconDefinition(FontAwesomeIcons.ns8, 'ns8'),
  new IconDefinition(FontAwesomeIcons.nutritionix, 'nutritionix'),
  new IconDefinition(FontAwesomeIcons.objectGroup, 'objectGroup'),
  new IconDefinition(FontAwesomeIcons.objectGroupO, 'objectGroupO'),
  new IconDefinition(FontAwesomeIcons.objectUngroup, 'objectUngroup'),
  new IconDefinition(FontAwesomeIcons.objectUngroupO, 'objectUngroupO'),
  new IconDefinition(FontAwesomeIcons.odnoklassniki, 'odnoklassniki'),
  new IconDefinition(
      FontAwesomeIcons.odnoklassnikiSquare, 'odnoklassnikiSquare'),
  new IconDefinition(FontAwesomeIcons.opencart, 'opencart'),
  new IconDefinition(FontAwesomeIcons.openid, 'openid'),
  new IconDefinition(FontAwesomeIcons.opera, 'opera'),
  new IconDefinition(FontAwesomeIcons.optinMonster, 'optinMonster'),
  new IconDefinition(FontAwesomeIcons.osi, 'osi'),
  new IconDefinition(FontAwesomeIcons.outdent, 'outdent'),
  new IconDefinition(FontAwesomeIcons.page4, 'page4'),
  new IconDefinition(FontAwesomeIcons.pagelines, 'pagelines'),
  new IconDefinition(FontAwesomeIcons.paintBrush, 'paintBrush'),
  new IconDefinition(FontAwesomeIcons.palfed, 'palfed'),
  new IconDefinition(FontAwesomeIcons.paperclip, 'paperclip'),
  new IconDefinition(FontAwesomeIcons.paperPlane, 'paperPlane'),
  new IconDefinition(FontAwesomeIcons.paperPlaneO, 'paperPlaneO'),
  new IconDefinition(FontAwesomeIcons.paragraph, 'paragraph'),
  new IconDefinition(FontAwesomeIcons.paste, 'paste'),
  new IconDefinition(FontAwesomeIcons.patreon, 'patreon'),
  new IconDefinition(FontAwesomeIcons.pause, 'pause'),
  new IconDefinition(FontAwesomeIcons.pauseCircle, 'pauseCircle'),
  new IconDefinition(FontAwesomeIcons.pauseCircleO, 'pauseCircleO'),
  new IconDefinition(FontAwesomeIcons.paw, 'paw'),
  new IconDefinition(FontAwesomeIcons.paypal, 'paypal'),
  new IconDefinition(FontAwesomeIcons.pencilAlt, 'pencilAlt'),
  new IconDefinition(FontAwesomeIcons.penSquare, 'penSquare'),
  new IconDefinition(FontAwesomeIcons.percent, 'percent'),
  new IconDefinition(FontAwesomeIcons.periscope, 'periscope'),
  new IconDefinition(FontAwesomeIcons.phabricator, 'phabricator'),
  new IconDefinition(FontAwesomeIcons.phoenixFramework, 'phoenixFramework'),
  new IconDefinition(FontAwesomeIcons.phone, 'phone'),
  new IconDefinition(FontAwesomeIcons.phoneSquare, 'phoneSquare'),
  new IconDefinition(FontAwesomeIcons.phoneVolume, 'phoneVolume'),
  new IconDefinition(FontAwesomeIcons.piedPiper, 'piedPiper'),
  new IconDefinition(FontAwesomeIcons.piedPiperAlt, 'piedPiperAlt'),
  new IconDefinition(FontAwesomeIcons.piedPiperPp, 'piedPiperPp'),
  new IconDefinition(FontAwesomeIcons.pinterest, 'pinterest'),
  new IconDefinition(FontAwesomeIcons.pinterestP, 'pinterestP'),
  new IconDefinition(FontAwesomeIcons.pinterestSquare, 'pinterestSquare'),
  new IconDefinition(FontAwesomeIcons.plane, 'plane'),
  new IconDefinition(FontAwesomeIcons.play, 'play'),
  new IconDefinition(FontAwesomeIcons.playCircle, 'playCircle'),
  new IconDefinition(FontAwesomeIcons.playCircleO, 'playCircleO'),
  new IconDefinition(FontAwesomeIcons.playstation, 'playstation'),
  new IconDefinition(FontAwesomeIcons.plug, 'plug'),
  new IconDefinition(FontAwesomeIcons.plus, 'plus'),
  new IconDefinition(FontAwesomeIcons.plusCircle, 'plusCircle'),
  new IconDefinition(FontAwesomeIcons.plusSquare, 'plusSquare'),
  new IconDefinition(FontAwesomeIcons.plusSquareO, 'plusSquareO'),
  new IconDefinition(FontAwesomeIcons.podcast, 'podcast'),
  new IconDefinition(FontAwesomeIcons.poundSign, 'poundSign'),
  new IconDefinition(FontAwesomeIcons.powerOff, 'powerOff'),
  new IconDefinition(FontAwesomeIcons.print, 'print'),
  new IconDefinition(FontAwesomeIcons.productHunt, 'productHunt'),
  new IconDefinition(FontAwesomeIcons.pushed, 'pushed'),
  new IconDefinition(FontAwesomeIcons.puzzlePiece, 'puzzlePiece'),
  new IconDefinition(FontAwesomeIcons.python, 'python'),
  new IconDefinition(FontAwesomeIcons.qq, 'qq'),
  new IconDefinition(FontAwesomeIcons.qrcode, 'qrcode'),
  new IconDefinition(FontAwesomeIcons.question, 'question'),
  new IconDefinition(FontAwesomeIcons.questionCircle, 'questionCircle'),
  new IconDefinition(FontAwesomeIcons.questionCircleO, 'questionCircleO'),
  new IconDefinition(FontAwesomeIcons.quora, 'quora'),
  new IconDefinition(FontAwesomeIcons.quoteLeft, 'quoteLeft'),
  new IconDefinition(FontAwesomeIcons.quoteRight, 'quoteRight'),
  new IconDefinition(FontAwesomeIcons.random, 'random'),
  new IconDefinition(FontAwesomeIcons.ravelry, 'ravelry'),
  new IconDefinition(FontAwesomeIcons.react, 'react'),
  new IconDefinition(FontAwesomeIcons.rebel, 'rebel'),
  new IconDefinition(FontAwesomeIcons.recycle, 'recycle'),
  new IconDefinition(FontAwesomeIcons.reddit, 'reddit'),
  new IconDefinition(FontAwesomeIcons.redditAlien, 'redditAlien'),
  new IconDefinition(FontAwesomeIcons.redditSquare, 'redditSquare'),
  new IconDefinition(FontAwesomeIcons.redo, 'redo'),
  new IconDefinition(FontAwesomeIcons.redoAlt, 'redoAlt'),
  new IconDefinition(FontAwesomeIcons.redRiver, 'redRiver'),
  new IconDefinition(FontAwesomeIcons.registered, 'registered'),
  new IconDefinition(FontAwesomeIcons.registeredO, 'registeredO'),
  new IconDefinition(FontAwesomeIcons.rendact, 'rendact'),
  new IconDefinition(FontAwesomeIcons.renren, 'renren'),
  new IconDefinition(FontAwesomeIcons.reply, 'reply'),
  new IconDefinition(FontAwesomeIcons.replyAll, 'replyAll'),
  new IconDefinition(FontAwesomeIcons.replyd, 'replyd'),
  new IconDefinition(FontAwesomeIcons.resolving, 'resolving'),
  new IconDefinition(FontAwesomeIcons.retweet, 'retweet'),
  new IconDefinition(FontAwesomeIcons.road, 'road'),
  new IconDefinition(FontAwesomeIcons.rocket, 'rocket'),
  new IconDefinition(FontAwesomeIcons.rocketchat, 'rocketchat'),
  new IconDefinition(FontAwesomeIcons.rockrms, 'rockrms'),
  new IconDefinition(FontAwesomeIcons.rss, 'rss'),
  new IconDefinition(FontAwesomeIcons.rssSquare, 'rssSquare'),
  new IconDefinition(FontAwesomeIcons.rubleSign, 'rubleSign'),
  new IconDefinition(FontAwesomeIcons.rupeeSign, 'rupeeSign'),
  new IconDefinition(FontAwesomeIcons.safari, 'safari'),
  new IconDefinition(FontAwesomeIcons.sass, 'sass'),
  new IconDefinition(FontAwesomeIcons.save, 'save'),
  new IconDefinition(FontAwesomeIcons.saveO, 'saveO'),
  new IconDefinition(FontAwesomeIcons.schlix, 'schlix'),
  new IconDefinition(FontAwesomeIcons.scribd, 'scribd'),
  new IconDefinition(FontAwesomeIcons.search, 'search'),
  new IconDefinition(FontAwesomeIcons.searchengin, 'searchengin'),
  new IconDefinition(FontAwesomeIcons.searchMinus, 'searchMinus'),
  new IconDefinition(FontAwesomeIcons.searchPlus, 'searchPlus'),
  new IconDefinition(FontAwesomeIcons.sellcast, 'sellcast'),
  new IconDefinition(FontAwesomeIcons.sellsy, 'sellsy'),
  new IconDefinition(FontAwesomeIcons.server, 'server'),
  new IconDefinition(FontAwesomeIcons.servicestack, 'servicestack'),
  new IconDefinition(FontAwesomeIcons.share, 'share'),
  new IconDefinition(FontAwesomeIcons.shareAlt, 'shareAlt'),
  new IconDefinition(FontAwesomeIcons.shareAltSquare, 'shareAltSquare'),
  new IconDefinition(FontAwesomeIcons.shareSquare, 'shareSquare'),
  new IconDefinition(FontAwesomeIcons.shareSquareO, 'shareSquareO'),
  new IconDefinition(FontAwesomeIcons.shekelSign, 'shekelSign'),
  new IconDefinition(FontAwesomeIcons.shieldAlt, 'shieldAlt'),
  new IconDefinition(FontAwesomeIcons.ship, 'ship'),
  new IconDefinition(FontAwesomeIcons.shirtsinbulk, 'shirtsinbulk'),
  new IconDefinition(FontAwesomeIcons.shoppingBag, 'shoppingBag'),
  new IconDefinition(FontAwesomeIcons.shoppingBasket, 'shoppingBasket'),
  new IconDefinition(FontAwesomeIcons.shoppingCart, 'shoppingCart'),
  new IconDefinition(FontAwesomeIcons.shower, 'shower'),
  new IconDefinition(FontAwesomeIcons.signal, 'signal'),
  new IconDefinition(FontAwesomeIcons.signInAlt, 'signInAlt'),
  new IconDefinition(FontAwesomeIcons.signLanguage, 'signLanguage'),
  new IconDefinition(FontAwesomeIcons.signOutAlt, 'signOutAlt'),
  new IconDefinition(FontAwesomeIcons.simplybuilt, 'simplybuilt'),
  new IconDefinition(FontAwesomeIcons.sistrix, 'sistrix'),
  new IconDefinition(FontAwesomeIcons.sitemap, 'sitemap'),
  new IconDefinition(FontAwesomeIcons.skyatlas, 'skyatlas'),
  new IconDefinition(FontAwesomeIcons.skype, 'skype'),
  new IconDefinition(FontAwesomeIcons.slack, 'slack'),
  new IconDefinition(FontAwesomeIcons.slackHash, 'slackHash'),
  new IconDefinition(FontAwesomeIcons.slidersH, 'slidersH'),
  new IconDefinition(FontAwesomeIcons.slideshare, 'slideshare'),
  new IconDefinition(FontAwesomeIcons.smile, 'smile'),
  new IconDefinition(FontAwesomeIcons.smileO, 'smileO'),
  new IconDefinition(FontAwesomeIcons.snapchat, 'snapchat'),
  new IconDefinition(FontAwesomeIcons.snapchatGhost, 'snapchatGhost'),
  new IconDefinition(FontAwesomeIcons.snapchatSquare, 'snapchatSquare'),
  new IconDefinition(FontAwesomeIcons.snowflake, 'snowflake'),
  new IconDefinition(FontAwesomeIcons.snowflakeO, 'snowflakeO'),
  new IconDefinition(FontAwesomeIcons.sort, 'sort'),
  new IconDefinition(FontAwesomeIcons.sortAlphaDown, 'sortAlphaDown'),
  new IconDefinition(FontAwesomeIcons.sortAlphaUp, 'sortAlphaUp'),
  new IconDefinition(FontAwesomeIcons.sortAmountDown, 'sortAmountDown'),
  new IconDefinition(FontAwesomeIcons.sortAmountUp, 'sortAmountUp'),
  new IconDefinition(FontAwesomeIcons.sortDown, 'sortDown'),
  new IconDefinition(FontAwesomeIcons.sortNumericDown, 'sortNumericDown'),
  new IconDefinition(FontAwesomeIcons.sortNumericUp, 'sortNumericUp'),
  new IconDefinition(FontAwesomeIcons.sortUp, 'sortUp'),
  new IconDefinition(FontAwesomeIcons.soundcloud, 'soundcloud'),
  new IconDefinition(FontAwesomeIcons.spaceShuttle, 'spaceShuttle'),
  new IconDefinition(FontAwesomeIcons.speakap, 'speakap'),
  new IconDefinition(FontAwesomeIcons.spinner, 'spinner'),
  new IconDefinition(FontAwesomeIcons.spotify, 'spotify'),
  new IconDefinition(FontAwesomeIcons.square, 'square'),
  new IconDefinition(FontAwesomeIcons.squareO, 'squareO'),
  new IconDefinition(FontAwesomeIcons.stackExchange, 'stackExchange'),
  new IconDefinition(FontAwesomeIcons.stackOverflow, 'stackOverflow'),
  new IconDefinition(FontAwesomeIcons.star, 'star'),
  new IconDefinition(FontAwesomeIcons.starHalf, 'starHalf'),
  new IconDefinition(FontAwesomeIcons.starHalfO, 'starHalfO'),
  new IconDefinition(FontAwesomeIcons.starO, 'starO'),
  new IconDefinition(FontAwesomeIcons.staylinked, 'staylinked'),
  new IconDefinition(FontAwesomeIcons.steam, 'steam'),
  new IconDefinition(FontAwesomeIcons.steamSquare, 'steamSquare'),
  new IconDefinition(FontAwesomeIcons.steamSymbol, 'steamSymbol'),
  new IconDefinition(FontAwesomeIcons.stepBackward, 'stepBackward'),
  new IconDefinition(FontAwesomeIcons.stepForward, 'stepForward'),
  new IconDefinition(FontAwesomeIcons.stethoscope, 'stethoscope'),
  new IconDefinition(FontAwesomeIcons.stickerMule, 'stickerMule'),
  new IconDefinition(FontAwesomeIcons.stickyNote, 'stickyNote'),
  new IconDefinition(FontAwesomeIcons.stickyNoteO, 'stickyNoteO'),
  new IconDefinition(FontAwesomeIcons.stop, 'stop'),
  new IconDefinition(FontAwesomeIcons.stopCircle, 'stopCircle'),
  new IconDefinition(FontAwesomeIcons.stopCircleO, 'stopCircleO'),
  new IconDefinition(FontAwesomeIcons.stopwatch, 'stopwatch'),
  new IconDefinition(FontAwesomeIcons.strava, 'strava'),
  new IconDefinition(FontAwesomeIcons.streetView, 'streetView'),
  new IconDefinition(FontAwesomeIcons.strikethrough, 'strikethrough'),
  new IconDefinition(FontAwesomeIcons.stripe, 'stripe'),
  new IconDefinition(FontAwesomeIcons.stripeS, 'stripeS'),
  new IconDefinition(FontAwesomeIcons.studiovinari, 'studiovinari'),
  new IconDefinition(FontAwesomeIcons.stumbleupon, 'stumbleupon'),
  new IconDefinition(FontAwesomeIcons.stumbleuponCircle, 'stumbleuponCircle'),
  new IconDefinition(FontAwesomeIcons.subscript, 'subscript'),
  new IconDefinition(FontAwesomeIcons.subway, 'subway'),
  new IconDefinition(FontAwesomeIcons.suitcase, 'suitcase'),
  new IconDefinition(FontAwesomeIcons.sun, 'sun'),
  new IconDefinition(FontAwesomeIcons.sunO, 'sunO'),
  new IconDefinition(FontAwesomeIcons.superpowers, 'superpowers'),
  new IconDefinition(FontAwesomeIcons.superscript, 'superscript'),
  new IconDefinition(FontAwesomeIcons.supple, 'supple'),
  new IconDefinition(FontAwesomeIcons.sync, 'sync'),
  new IconDefinition(FontAwesomeIcons.syncAlt, 'syncAlt'),
  new IconDefinition(FontAwesomeIcons.table, 'table'),
  new IconDefinition(FontAwesomeIcons.tablet, 'tablet'),
  new IconDefinition(FontAwesomeIcons.tabletAlt, 'tabletAlt'),
  new IconDefinition(FontAwesomeIcons.tachometerAlt, 'tachometerAlt'),
  new IconDefinition(FontAwesomeIcons.tag, 'tag'),
  new IconDefinition(FontAwesomeIcons.tags, 'tags'),
  new IconDefinition(FontAwesomeIcons.tasks, 'tasks'),
  new IconDefinition(FontAwesomeIcons.taxi, 'taxi'),
  new IconDefinition(FontAwesomeIcons.telegram, 'telegram'),
  new IconDefinition(FontAwesomeIcons.telegramPlane, 'telegramPlane'),
  new IconDefinition(FontAwesomeIcons.tencentWeibo, 'tencentWeibo'),
  new IconDefinition(FontAwesomeIcons.terminal, 'terminal'),
  new IconDefinition(FontAwesomeIcons.textHeight, 'textHeight'),
  new IconDefinition(FontAwesomeIcons.textWidth, 'textWidth'),
  new IconDefinition(FontAwesomeIcons.th, 'th'),
  new IconDefinition(FontAwesomeIcons.themeisle, 'themeisle'),
  new IconDefinition(FontAwesomeIcons.thermometerEmpty, 'thermometerEmpty'),
  new IconDefinition(FontAwesomeIcons.thermometerFull, 'thermometerFull'),
  new IconDefinition(FontAwesomeIcons.thermometerHalf, 'thermometerHalf'),
  new IconDefinition(FontAwesomeIcons.thermometerQuarter, 'thermometerQuarter'),
  new IconDefinition(
      FontAwesomeIcons.thermometerThreeQuarters, 'thermometerThreeQuarters'),
  new IconDefinition(FontAwesomeIcons.thLarge, 'thLarge'),
  new IconDefinition(FontAwesomeIcons.thList, 'thList'),
  new IconDefinition(FontAwesomeIcons.thumbsDown, 'thumbsDown'),
  new IconDefinition(FontAwesomeIcons.thumbsDownO, 'thumbsDownO'),
  new IconDefinition(FontAwesomeIcons.thumbsUp, 'thumbsUp'),
  new IconDefinition(FontAwesomeIcons.thumbsUpO, 'thumbsUpO'),
  new IconDefinition(FontAwesomeIcons.thumbtack, 'thumbtack'),
  new IconDefinition(FontAwesomeIcons.ticketAlt, 'ticketAlt'),
  new IconDefinition(FontAwesomeIcons.times, 'times'),
  new IconDefinition(FontAwesomeIcons.timesCircle, 'timesCircle'),
  new IconDefinition(FontAwesomeIcons.timesCircleO, 'timesCircleO'),
  new IconDefinition(FontAwesomeIcons.tint, 'tint'),
  new IconDefinition(FontAwesomeIcons.toggleOff, 'toggleOff'),
  new IconDefinition(FontAwesomeIcons.toggleOn, 'toggleOn'),
  new IconDefinition(FontAwesomeIcons.trademark, 'trademark'),
  new IconDefinition(FontAwesomeIcons.train, 'train'),
  new IconDefinition(FontAwesomeIcons.transgender, 'transgender'),
  new IconDefinition(FontAwesomeIcons.transgenderAlt, 'transgenderAlt'),
  new IconDefinition(FontAwesomeIcons.trash, 'trash'),
  new IconDefinition(FontAwesomeIcons.trashAlt, 'trashAlt'),
  new IconDefinition(FontAwesomeIcons.trashAltO, 'trashAltO'),
  new IconDefinition(FontAwesomeIcons.tree, 'tree'),
  new IconDefinition(FontAwesomeIcons.trello, 'trello'),
  new IconDefinition(FontAwesomeIcons.tripadvisor, 'tripadvisor'),
  new IconDefinition(FontAwesomeIcons.trophy, 'trophy'),
  new IconDefinition(FontAwesomeIcons.truck, 'truck'),
  new IconDefinition(FontAwesomeIcons.tty, 'tty'),
  new IconDefinition(FontAwesomeIcons.tumblr, 'tumblr'),
  new IconDefinition(FontAwesomeIcons.tumblrSquare, 'tumblrSquare'),
  new IconDefinition(FontAwesomeIcons.tv, 'tv'),
  new IconDefinition(FontAwesomeIcons.twitch, 'twitch'),
  new IconDefinition(FontAwesomeIcons.twitter, 'twitter'),
  new IconDefinition(FontAwesomeIcons.twitterSquare, 'twitterSquare'),
  new IconDefinition(FontAwesomeIcons.typo3, 'typo3'),
  new IconDefinition(FontAwesomeIcons.uber, 'uber'),
  new IconDefinition(FontAwesomeIcons.uikit, 'uikit'),
  new IconDefinition(FontAwesomeIcons.umbrella, 'umbrella'),
  new IconDefinition(FontAwesomeIcons.underline, 'underline'),
  new IconDefinition(FontAwesomeIcons.undo, 'undo'),
  new IconDefinition(FontAwesomeIcons.undoAlt, 'undoAlt'),
  new IconDefinition(FontAwesomeIcons.uniregistry, 'uniregistry'),
  new IconDefinition(FontAwesomeIcons.universalAccess, 'universalAccess'),
  new IconDefinition(FontAwesomeIcons.university, 'university'),
  new IconDefinition(FontAwesomeIcons.unlink, 'unlink'),
  new IconDefinition(FontAwesomeIcons.unlock, 'unlock'),
  new IconDefinition(FontAwesomeIcons.unlockAlt, 'unlockAlt'),
  new IconDefinition(FontAwesomeIcons.untappd, 'untappd'),
  new IconDefinition(FontAwesomeIcons.upload, 'upload'),
  new IconDefinition(FontAwesomeIcons.usb, 'usb'),
  new IconDefinition(FontAwesomeIcons.user, 'user'),
  new IconDefinition(FontAwesomeIcons.userCircle, 'userCircle'),
  new IconDefinition(FontAwesomeIcons.userCircleO, 'userCircleO'),
  new IconDefinition(FontAwesomeIcons.userMd, 'userMd'),
  new IconDefinition(FontAwesomeIcons.userO, 'userO'),
  new IconDefinition(FontAwesomeIcons.userPlus, 'userPlus'),
  new IconDefinition(FontAwesomeIcons.users, 'users'),
  new IconDefinition(FontAwesomeIcons.userSecret, 'userSecret'),
  new IconDefinition(FontAwesomeIcons.userTimes, 'userTimes'),
  new IconDefinition(FontAwesomeIcons.ussunnah, 'ussunnah'),
  new IconDefinition(FontAwesomeIcons.utensils, 'utensils'),
  new IconDefinition(FontAwesomeIcons.utensilSpoon, 'utensilSpoon'),
  new IconDefinition(FontAwesomeIcons.vaadin, 'vaadin'),
  new IconDefinition(FontAwesomeIcons.venus, 'venus'),
  new IconDefinition(FontAwesomeIcons.venusDouble, 'venusDouble'),
  new IconDefinition(FontAwesomeIcons.venusMars, 'venusMars'),
  new IconDefinition(FontAwesomeIcons.viacoin, 'viacoin'),
  new IconDefinition(FontAwesomeIcons.viadeo, 'viadeo'),
  new IconDefinition(FontAwesomeIcons.viadeoSquare, 'viadeoSquare'),
  new IconDefinition(FontAwesomeIcons.viber, 'viber'),
  new IconDefinition(FontAwesomeIcons.video, 'video'),
  new IconDefinition(FontAwesomeIcons.vimeo, 'vimeo'),
  new IconDefinition(FontAwesomeIcons.vimeoSquare, 'vimeoSquare'),
  new IconDefinition(FontAwesomeIcons.vimeoV, 'vimeoV'),
  new IconDefinition(FontAwesomeIcons.vine, 'vine'),
  new IconDefinition(FontAwesomeIcons.vk, 'vk'),
  new IconDefinition(FontAwesomeIcons.vnv, 'vnv'),
  new IconDefinition(FontAwesomeIcons.volumeDown, 'volumeDown'),
  new IconDefinition(FontAwesomeIcons.volumeOff, 'volumeOff'),
  new IconDefinition(FontAwesomeIcons.volumeUp, 'volumeUp'),
  new IconDefinition(FontAwesomeIcons.vuejs, 'vuejs'),
  new IconDefinition(FontAwesomeIcons.weibo, 'weibo'),
  new IconDefinition(FontAwesomeIcons.weixin, 'weixin'),
  new IconDefinition(FontAwesomeIcons.whatsapp, 'whatsapp'),
  new IconDefinition(FontAwesomeIcons.whatsappSquare, 'whatsappSquare'),
  new IconDefinition(FontAwesomeIcons.wheelchair, 'wheelchair'),
  new IconDefinition(FontAwesomeIcons.whmcs, 'whmcs'),
  new IconDefinition(FontAwesomeIcons.wifi, 'wifi'),
  new IconDefinition(FontAwesomeIcons.wikipediaW, 'wikipediaW'),
  new IconDefinition(FontAwesomeIcons.windowClose, 'windowClose'),
  new IconDefinition(FontAwesomeIcons.windowCloseO, 'windowCloseO'),
  new IconDefinition(FontAwesomeIcons.windowMaximize, 'windowMaximize'),
  new IconDefinition(FontAwesomeIcons.windowMaximizeO, 'windowMaximizeO'),
  new IconDefinition(FontAwesomeIcons.windowMinimize, 'windowMinimize'),
  new IconDefinition(FontAwesomeIcons.windowRestore, 'windowRestore'),
  new IconDefinition(FontAwesomeIcons.windowRestoreO, 'windowRestoreO'),
  new IconDefinition(FontAwesomeIcons.windows, 'windows'),
  new IconDefinition(FontAwesomeIcons.wonSign, 'wonSign'),
  new IconDefinition(FontAwesomeIcons.wordpress, 'wordpress'),
  new IconDefinition(FontAwesomeIcons.wordpressSimple, 'wordpressSimple'),
  new IconDefinition(FontAwesomeIcons.wpbeginner, 'wpbeginner'),
  new IconDefinition(FontAwesomeIcons.wpexplorer, 'wpexplorer'),
  new IconDefinition(FontAwesomeIcons.wpforms, 'wpforms'),
  new IconDefinition(FontAwesomeIcons.wrench, 'wrench'),
  new IconDefinition(FontAwesomeIcons.xbox, 'xbox'),
  new IconDefinition(FontAwesomeIcons.xing, 'xing'),
  new IconDefinition(FontAwesomeIcons.xingSquare, 'xingSquare'),
  new IconDefinition(FontAwesomeIcons.yahoo, 'yahoo'),
  new IconDefinition(FontAwesomeIcons.yandex, 'yandex'),
  new IconDefinition(
      FontAwesomeIcons.yandexInternational, 'yandexInternational'),
  new IconDefinition(FontAwesomeIcons.yCombinator, 'yCombinator'),
  new IconDefinition(FontAwesomeIcons.yelp, 'yelp'),
  new IconDefinition(FontAwesomeIcons.yenSign, 'yenSign'),
  new IconDefinition(FontAwesomeIcons.yoast, 'yoast'),
  new IconDefinition(FontAwesomeIcons.youtube, 'youtube'),
];

class IconDefinition implements Comparable {
  final IconData iconData;
  final String title;

  IconDefinition(this.iconData, this.title);

  @override
  String toString() => 'IconDefinition{iconData: $iconData, title: $title}';

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is IconDefinition &&
          runtimeType == other.runtimeType &&
          iconData == other.iconData &&
          title == other.title;

  @override
  int get hashCode => iconData.hashCode ^ title.hashCode;

  @override
  int compareTo(other) => title.compareTo(other.title);
}
